@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -41,7 +41,7 @@ import logging.config
 from getpass import getuser
 
 __prog__ = "pyformex"
-__version__ = "2.6"
+__version__ = "3.0"
 __revision__ = __version__
 __branch__ = "master"
 Copyright = 'Copyright (C) 2004-2021 Benedict Verhegghe'
@@ -74,10 +74,10 @@ started = False
 #########  Check Python version #############
 
 # intended Python version
-# We only support 3.6+
-minimal_version = 0x03060000
-target_version = 0x03070000
-future_version = 0x03080000
+# We only support 3.7+
+minimal_version = 0x03070000
+target_version = 0x03090000
+future_version = 0x030A0000
 
 
 def major(v):
@@ -101,8 +101,8 @@ if sys.hexversion < minimal_version:
     m = human_version(minimal_version)
     startup_warnings += f"""
 #######################################################################
-##  Your Python version is {y}, but pyFormex requires Python >= {m}. ##
-##  We advice you to upgrade your Python version.                    ##
+##  Your Python version is {y}, but pyFormex requires Python >= {m}.
+##  We advice you to upgrade your Python version.
 #######################################################################
 """
     print(startup_warnings)
@@ -114,10 +114,10 @@ if sys.hexversion & 0xFFFF0000 > target_version:
     t = human_version(target_version)
     startup_warnings += f"""
 #######################################################################
-##  Your Python version is {y}, but pyFormex has only been tested    ##
-##  with Python <= {t}. We expect pyFormex to run correctly with     ##
-##  your Python version, but if you encounter problems, please       ##
-##  contact the developers at http://pyformex.org.                   ##
+##  Your Python version is {y}, but pyFormex has only been tested
+##  with Python <= {t}. We expect pyFormex to run correctly with
+##  your Python version, but if you encounter problems, please
+##  contact the developers at http://pyformex.org.
 #######################################################################
 """
 
@@ -208,7 +208,11 @@ logger.info(f"{fullVersion()} start on Python{human_version(sys.hexversion)}")
 
 ########## acceleration libraries ##############
 
-libraries = ['misc_', 'nurbs_']
+# Are we importing from Sphinx doc generator?
+#sphinx = installtype == 'G' and 'sphinx' in sys.modules
+sphinx = 'sphinx' in sys.modules
+
+libraries = ['misc_', 'nurbs_', 'clust_']
 
 ########## Special adjustements for source versions ############
 
@@ -222,17 +226,21 @@ if installtype == 'G':
             str(cmd), stdout=subprocess.PIPE, shell=True, universal_newlines=True
         )
         out, err = P.communicate()
+        if P.returncode:
+            print(out)
+            print(err)
         return P.returncode, out, err
 
     # Clean the source tree
     source_clean = pyformexdir / 'source_clean'
     if source_clean.exists():
         try:
-            import importlib
-            suffix = importlib.machinery.EXTENSION_SUFFIXES[0]
+            from importlib import machinery
+            suffix = machinery.EXTENSION_SUFFIXES[0]
             cmd = f"{source_clean} --keep_modules '*{suffix}'"
             run_cmd(cmd)
-        except Exception:
+        except Exception as e:
+            print(str(e))
             print(f"Error while executing {source_clean}\n"
                   "Ignore error and continue")
 
@@ -247,19 +255,21 @@ if installtype == 'G':
             ext = '.so'
         msg = ''
         for lib in libraries:
-            src = libdir / lib + '.c'
+            if lib.startswith('_'):
+                src = libdir / lib + '.pyx'
+            else:
+                src = libdir / lib + '.c'
             obj = libdir / lib + ext
             if not obj.exists() or obj.mtime < src.mtime:
                 msg += f"\nThe compiled library '{lib}' is not up to date!"
         return msg
 
     msg = checkLibraries()
-    if msg:
+    if msg and not sphinx:
         print(msg)
         print("Rebuilding pyFormex libraries, please wait")
         target = 'lib3'
-        cmd = f"cd {pyformexdir.parent}; make {target}"
-        print(f"Running command: {cmd}")
+        cmd = f"cd {pyformexdir.parent}; PYTHON={sys.executable} make {target}"
         run_cmd(cmd)
         msg = checkLibraries()
 
@@ -268,7 +278,7 @@ if installtype == 'G':
         msg += f"""
 
 I had a problem rebuilding the libraries in {libdir}.
-You should probably exit pyFormex, fix the problem first and then restart pyFormex.
+You should probably exit pyFormex, fix the problem and then restart pyFormex.
 """
     startup_warnings += msg
 
@@ -276,7 +286,7 @@ You should probably exit pyFormex, fix the problem first and then restart pyForm
 
     def set_revision():
         global __revision__
-        cmd = f'cd {pyformexdir} && git describe --always'
+        cmd = f"cd {pyformexdir} && git describe --always"
         sta, out, err = run_cmd(cmd)
         if sta == 0:
             __revision__ = out.split('\n')[0].strip()
@@ -322,10 +332,6 @@ class options:
     uselib = False  # initial default to keep sphinx happy
 
 
-# Are we importing from Sphinx doc generator?
-#sphinx = installtype == 'G' and 'sphinx' in sys.modules
-sphinx = 'sphinx' in sys.modules
-
 # Important pyFormex globals
 PF = {}  # explicitely exported globals
 GS = None # only set in gui mode
@@ -478,5 +484,15 @@ refcfg = None  # the reference configuration
 preffile = None  # the file where the preferenced configuration will be saved
 
 #print(f"Current path is {Path.cwd()}")
+#def except_hook(cls, exception, traceback):
+#    sys.__excepthook__(cls, exception, traceback)
+
+# if __name__ == "__main__":
+
+#     import sys
+#     sys.excepthook = except_hook
+
+#print(f"EXCEPTHOOK builtin {id(sys.__excepthook__)}")
+#print(f"EXCEPTHOOK active  {id(sys.excepthook)}")
 
 # End
