@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -41,7 +41,6 @@ from pyformex.examples.Cube import cube_quad
 
 def run():
 
-
     colormode = [None, 'Single', 'Face', 'Full']
     n = len(colormode)
     obj = OrderedDict({})
@@ -61,9 +60,9 @@ def run():
         tmpdir = utils.TempDir()
         indir = tmpdir.path
 
-    writeGeomFile(indir / 'test.pgf', obj, sep=' ')
+    filewrite.writePGF(indir / 'test.pgf', obj)
 
-    oobj = readGeomFile(indir / 'test.pgf')
+    oobj = readGeometry(indir / 'test.pgf')
     for vp, color in enumerate(colormode[:4]):
         viewport(vp+n)
         clear()
