@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -42,7 +42,6 @@ from pyformex.plugins import curve
 from pyformex import simple
 
 def run():
-    smoothwire()
     # GEOMETRICAL PARAMETERS FOR HE200B wide flange beam
     h = 200.  # beam height
     b = 200.  # flange width
@@ -74,39 +73,50 @@ def run():
     Section = Full.toMesh()
 
     clear()
+    smoothwire()
     draw(Section, name='Section', color=red)
+    methods = ['Cancel', 'Sweep', 'Connect', 'Extrude', 'ExtrudeQuadratic', 'Revolve', 'RevolveLoop', 'All']
 
-    method = ask("Choose extrude method:", ['Cancel', 'Sweep', 'Connect', 'Extrude', 'ExtrudeQuadratic', 'RevolveLoop', 'Revolve'])
+    method = ask("Choose extrude method:", methods)
+    if method == 'All':
+        methods = methods[1:-1]
+    elif method != 'Cancel':
+        methods = [method]
+    else:
+        return
 
-    t = timer.Timer(auto=True)
-    with t.tag(f"Computing ({method})"):
-        if method == 'Sweep':
-            path = simple.line([0, 0, 0], [0, 0, l], el).toCurve()
-            Beam = Section.sweep(path, normal=[0., 0., 1.], upvector=[0., 1., 0.])
+    n = len(methods)
+    # layout(n,3)
+    t = Timer(auto=True)
+    for i, method in enumerate(methods):
+        with t.tag(f"Computing ({method})"):
+            if method == 'Sweep':
+                path = simple.line([0, 0, 0], [0, 0, l], el).toCurve()
+                Beam = Section.sweep(path, normal=[0., 0., 1.], upvector=[0., 1., 0.])
 
-        elif method == 'Connect':
-            Section1 = Section.trl([0, 0, l])
-            Beam = Section.connect(Section1, el)
+            elif method == 'Connect':
+                Section1 = Section.trl([0, 0, l])
+                Beam = Section.connect(Section1, el)
 
-        elif method == 'Extrude':
-            Beam = Section.extrude(el, dir=2, length=l)
+            elif method == 'Extrude':
+                Beam = Section.extrude(el, dir=2, length=l)
 
-        elif method == 'ExtrudeQuadratic':
-            Section = Section.convert('quad9')
-            Beam = Section.extrude(el, dir=2, length=l, degree=2)
+            elif method == 'ExtrudeQuadratic':
+                Section2 = Section.convert('quad9')
+                Beam = Section2.extrude(el, dir=2, length=l, degree=2)
 
-        elif method == 'Revolve':
-            Beam = Section.revolve(el, axis=1, angle=60., around=[-l, 0., 0.])
+            elif method == 'Revolve':
+                Beam = Section.revolve(el, axis=1, angle=60., around=[-l, 0., 0.])
 
-        elif method == 'RevolveLoop':
-            Beam = Section.revolve(el, axis=1, angle=240., around=[-l, 0., 0.], loop=True)
+            elif method == 'RevolveLoop':
+                Beam = Section.revolve(el, axis=1, angle=240., around=[-l, 0., 0.], loop=True)
 
-        else:
-            return
-
-    with t.tag("Drawing"):
-        draw(Beam.getBorderMesh(), name='Beam', color='red', linewidth=2)
-    export({'Beam': Beam})
+        # viewport(i)
+        # smoothwire()
+        with t.tag("Drawing"):
+            clear()
+            draw(Beam.getBorderMesh(), name='Beam', color='red', linewidth=2)
+        export({f'Beam_{method}': Beam})
 
 
 if __name__ == '__draw__':
