@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -53,21 +53,30 @@ def readPGF(filename, count=-1):
     A pyFormex Geometry File can store multiple geometrical objects in a
     native format that can be efficiently read back into pyformex.
     The format is portable over different pyFormex versions and
-    even to other software.
+    even to other software, as the format is stable and documented.
+    This reader can restore subclasses of :class:`Geometry`:
+    :class:`Formex`, :class:`Mesh`, :class:`TriSurface`,
+    :class:`PolyLine`, :class:`BezierSpline`, :class:`NurbsCurve`,
+    with their stored attributes (name, color, field variables).
 
     Parameters
     ----------
     filename: :term:`path_like`
         The name of an existing pyFormex Geometry File. If the
-        filename ends on '.gz', it is considered to be a gzipped file and
-        will be uncompressed transparently during the reading.
+        filename ends on '.gz' or '.bz2', it is considered to be a gzipped,
+        resp. bzipped file and it will transparently be uncompressed
+        during reading.
+    count: int, optional
+        If specified, no more than this number of objects will be read.
 
     Returns
     -------
     dict
         A dictionary with the geometric objects read from the file.
-        If object names were stored in the file, they will be used as the keys.
-        Else, default names will be provided.
+        If the file contains the object names, these are used as the keys.
+        Else, default names are provided.
+        If the file contains attributes (colors, fields) for an object,
+        these will also be restored.
     """
     from pyformex import geomfile
     filename = Path(filename)
@@ -78,13 +87,8 @@ def readPGF(filename, count=-1):
     return objects
 
 
-def readOFF(filename):
-    """Read a surface mesh from an OFF file.
-
-    Note
-    ----
-    All the faces in the file should have 3 vertices.
-    There should be no comments lines on the file.
+def readOFF(filename, mplex=None):
+    """Read polygon meshes from an OFF file.
 
     Parameters
     ----------
@@ -92,13 +96,20 @@ def readOFF(filename):
         The name of a file in OFF format, commonly having a suffix '.off'.
         If the name ends with '.off.gz' or '.off.bz2', then the file will
         transparently be uncompressed during reading.
+    mplex: int, optional
+        The maximum plexitude of the output polygons. If provided, polygons
+        with a plexitude higher that mplex will be split into smaller ones.
+        For example, with mplex=4, polygons with 5 or more vertices will be
+        split into quads and triangles. Likewise, mplex=3 will split all
+        polygons into triangles.
 
     Returns
     -------
     coords: float array (ncoords, 3)
         The coordinates of all vertices.
-    elems: int array (nelems,3)
-        The element connectivity table.
+    faces: dict
+        A dict where the keys are plexitudes (<= mplex) and the values are
+        the Connectivity tables of all the polygons of the plexitude.
 
     Examples
     --------
@@ -108,34 +119,82 @@ def readOFF(filename):
     >>> writeOFF(f, M)
     >>> coords, elems = readOFF(f)[:2]
     >>> print(coords)
-    [[ 0.  0.  0.]
-     [ 1.  0.  0.]
-     [ 1.  1.  0.]
-     [ 0.  1.  0.]]
+    [[0. 0. 0.]
+     [1. 0. 0.]
+     [1. 1. 0.]
+     [0. 1. 0.]]
     >>> print(elems)
-    [[0 1 2]
-     [2 3 0]]
+    {3: array([[0, 1, 2],
+           [2, 3, 0]])}
     """
+    from pyformex.geomtools import splitPolygon
+
     filename = Path(filename)
     pf.verbose(1, f"Read OFF file {filename.absolute()}")
+    class STAGE():
+        INIT, HEADER, COORDS, ELEMS, EDGES = range(5)
+
+    coords = None
+    faces = {}
+    stage = STAGE.INIT
     with utils.File(filename, 'r') as fil:
-        head = fil.readline().strip()
-        if head != "OFF":
-            raise ValueError(f"{filename} is not an OFF file!")
-        nnodes, nelems, nedges = [int(i) for i in fil.readline().split()]
-        coords = np.fromfile(file=fil, dtype=at.Float, count=3 * nnodes, sep=' ')
-        # elems have number of vertices + 3 vertex numbers
-        elems = np.fromfile(file=fil, dtype=np.int32, count=4 * nelems, sep=' ')
-        # edges have number of vertices + 2 vertex numbers
-        edges = np.fromfile(file=fil, dtype=np.int32, count=3 * nedges, sep=' ')
-    pf.verbose(2, f"Got {nnodes} nodes and {nelems} elems")
-    coords = coords.reshape(nnodes, 3)
-    elems = elems.reshape(nelems, 4)
-    edges = edges.reshape(nedges, 3)
-    if (elems[:,0] != 3).any() or (edges[:,0] != 2).any():
-        raise ValueError("Currently we can only read OFF files consisting"
-                         "off pure triangles and files (sorted).")
-    return coords, elems[:, 1:], edges[:, 1:]
+        for line in fil:
+            comment = line.find('#')
+            if comment >= 0:
+                line = line[:comment]
+                if not line:
+                    continue
+            line = line.strip()
+            if not line:
+                continue
+            if stage == STAGE.INIT:
+                stage += 1
+                if "OFF" in line:
+                    if line != 'OFF':
+                        raise ValueError(
+                            f"I can not yet read {line} files, only OFF!")
+                    continue
+            if stage == STAGE.HEADER:
+                nnodes, nelems, nedges = [int(i) for i in line.split()]
+                pf.verbose(2, f"  {nnodes} vertices, {nelems} faces, {nedges} edges")
+                stage += 1
+                # Prepare for reading nodes
+                coords = np.empty((nnodes,3), dtype=at.Float)
+                i = 0
+            elif stage == STAGE.COORDS:
+                s = line.split()
+                coords[i] = [float(si) for si in s]
+                i += 1
+                if i >= nnodes:
+                    stage += 1
+                    i = 0
+            elif stage == STAGE.ELEMS:
+                s = line.split()
+                n = int(s[0])
+                face = [ int(si) for si in s[1:n+1] ]
+                if n not in faces:
+                    faces[n] = []
+                faces[n].append(face)
+                i += 1
+                if i >= nelems:
+                    stage += 1
+                    i = 0
+            elif stage == STAGE.EDGES:
+                pv.verbose(2, "Reading of edges is not yet implemented")
+
+        # Convert faces lists to arrays
+        nfaces = 0
+        for n in faces:
+            faces[n] = np.array(faces[n], dtype=at.Int)
+            nfaces += faces[n].shape[0]
+
+    if coords is None or not faces:
+        raise ValueError("Could not read any vertices and/or faces")
+    if mplex and max(faces) > mplex:
+        faces = splitPolygon(coords, faces, mplex)
+
+    pf.verbose(2, f"Got {coords.shape[0]} nodes, {[faces[e].shape for e in faces]} faces")
+    return coords, faces
 
 
 def readOBJ(filename, mplex=None):
@@ -178,10 +237,10 @@ def readOBJ(filename, mplex=None):
     >>> writeOBJ(f, M)
     >>> coords, elems = readOBJ(f)
     >>> print(coords)
-    [[ 0.  0.  0.]
-     [ 1.  0.  0.]
-     [ 1.  1.  0.]
-     [ 0.  1.  0.]]
+    [[0.  0.  0.]
+     [1.  0.  0.]
+     [1.  1.  0.]
+     [0.  1.  0.]]
     >>> print(elems)
     {4: array([[0, 1, 2, 3]])}
     """
@@ -271,10 +330,10 @@ def readPLY(filename, mplex=None):
     >>> writePLY(f, M.coords, {4:M.elems})
     >>> coords, elems = readPLY(f)
     >>> print(coords)
-    [[ 0.  0.  0.]
-     [ 1.  0.  0.]
-     [ 1.  1.  0.]
-     [ 0.  1.  0.]]
+    [[0.  0.  0.]
+     [1.  0.  0.]
+     [1.  1.  0.]
+     [0.  1.  0.]]
     >>> print(elems)
     {4: array([[0, 1, 2, 3]])}
     """
@@ -336,10 +395,10 @@ def readGTS(filename):
     >>> writeGTS(f, M.toSurface())
     >>> coords, edges, faces = readGTS(f)
     >>> print(coords)
-    [[ 0.  0.  0.]
-     [ 1.  0.  0.]
-     [ 1.  1.  0.]
-     [ 0.  1.  0.]]
+    [[0. 0. 0.]
+     [1. 0. 0.]
+     [1. 1. 0.]
+     [0. 1. 0.]]
     >>> print(edges)
     [[0 1]
      [2 0]
@@ -414,31 +473,31 @@ def readSTL(filename):
     >>> writeSTL(f, M.toFormex().coords, binary=True, color=[255,0,0,128])
     >>> coords, normals, color = readSTL(f)
     >>> print(coords)
-    [[[ 0.  0.  0.]
-      [ 1.  0.  0.]
-      [ 1.  1.  0.]]
+    [[[0.  0.  0.]
+      [1.  0.  0.]
+      [1.  1.  0.]]
     <BLANKLINE>
-     [[ 1.  1.  0.]
-      [ 0.  1.  0.]
-      [ 0.  0.  0.]]]
+     [[1.  1.  0.]
+      [0.  1.  0.]
+      [0.  0.  0.]]]
     >>> print(normals)
-    [[ 0.  0.  1.]
-     [ 0.  0.  1.]]
+    [[0.  0.  1.]
+     [0.  0.  1.]]
     >>> print(color)
     (1.0, 0.0, 0.0)
     >>> writeSTL(f, M.toFormex().coords, binary=False)
     >>> coords, normals, color = readSTL(f)
     >>> print(coords)
-    [[[ 0.  0.  0.]
-      [ 1.  0.  0.]
-      [ 1.  1.  0.]]
+    [[[0.  0.  0.]
+      [1.  0.  0.]
+      [1.  1.  0.]]
     <BLANKLINE>
-     [[ 1.  1.  0.]
-      [ 0.  1.  0.]
-      [ 0.  0.  0.]]]
+     [[1.  1.  0.]
+      [0.  1.  0.]
+      [0.  0.  0.]]]
     >>> print(normals)
-    [[ 0.  0.  1.]
-     [ 0.  0.  1.]]
+    [[0.  0.  1.]
+     [0.  0.  1.]]
     """
     filename = Path(filename)
     pf.verbose(1, f"Read STL file {filename.absolute()}")
@@ -603,32 +662,35 @@ def read_stl_asc(fil):
     return coords, normals
 
 
-def read_stl_cvt(filename, intermediate=None):
-    """Read a surface from .stl file.
+# REMOVED 2021-11-15
+# No longer used/needed as we have direct STL reader
+# def read_stl_cvt(filename, intermediate=None):
+#     """Read a surface from .stl file.
 
-    This is done by first coverting the .stl to .gts or .off format.
-    The name of the intermediate file may be specified. If not, it will be
-    generated by changing the extension of filename to '.gts' or '.off' depending
-    on the setting of the 'surface/stlread' config setting.
+#     This is done by first coverting the .stl to .gts or .off format.
+#     The name of the intermediate file may be specified. If not, it will be
+#     generated by changing the extension of filename to '.gts' or '.off' depending
+#     on the setting of the 'surface/stlread' config setting.
 
-    Return a coords,edges,faces or a coords,elems tuple, depending on the
-    intermediate format.
-    """
-    ofn, sta, out = stlConvert(filename, intermediate)
-    if sta:
-        pf.debug("Error during conversion of file '%s' to '%s'" % (filename, ofn))
-        pf.debug(out)
-        return ()
+#     Return a coords,edges,faces or a coords,elems tuple, depending on the
+#     intermediate format.
+#     """
+#     ofn, sta, out = stlConvert(filename, intermediate)
+#     if sta:
+#         pf.debug("Error during conversion of file '%s' to '%s'" % (filename, ofn))
+#         pf.debug(out)
+#         return ()
 
-    ftype, compr = ofn.ftype_compr()
-    if ftype == 'off':
-        return readOFF(ofn)
-    elif ftype == 'gts':
-        return readGTS(ofn)
+#     ftype, compr = ofn.ftype_compr()
+#     if ftype == 'off':
+#         return readOFF(ofn)
+#     elif ftype == 'gts':
+#         return readGTS(ofn)
 
 
+# TODO: this should unzip compressed input files and zip compressed output
+# TODO: remove the default outname and warn if not specified
 def stlConvert(stlname, outname=None, binary=False, options='-d'):
-    # TODO: this should unzip compressed input files and zip compressed output
     """Convert an .stl file to .off or .gts or binary .stl format.
 
     Parameters
@@ -901,8 +963,8 @@ def readNEU(filename, return_numbering=False):
      ncoords=64; nelems=27;  nplex=8; eltype=Hex8
     >>> print(M)
     Mesh: nnodes: 64, nelems: 27, nplex: 8, level: 3, eltype: hex8
-      BBox: [ 0.  0.  0.], [ 1.  1.  1.]
-      Size: [ 1.  1.  1.]
+      BBox: [0.  0.  0.], [1.  1.  1.]
+      Size: [1.  1.  1.]
       Volume: 0.999999...
     """
 
