@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -43,7 +43,7 @@ import pyformex as pf
 from pyformex import Path
 from pyformex import utils
 
-BINDINGS = ('pyside2', 'pyside', 'pyqt5', 'pyqt4')
+BINDINGS = ('pyside2', 'pyqt5')
 bindings = pf.cfg['gui/bindings'].lower()
 
 if bindings in BINDINGS:
@@ -61,44 +61,8 @@ if bindings == 'pyside2':
     from PySide2 import QtCore, QtGui, QtOpenGL, QtWidgets
     from PySide2.QtCore import Signal, Slot
 
-elif bindings == 'pyside':
-    from PySide import QtCore, QtGui, QtOpenGL
-    import PySide.QtGui as QtWidgets
-    from PySide.QtCore import Signal, Slot
-
-elif bindings == 'pyqt4':
-    import sip
-    try:
-        sip.setapi('QDate', 2)
-        sip.setapi('QDateTime', 2)
-        sip.setapi('QString', 2)
-        sip.setapi('QTextStream', 2)
-        sip.setapi('QTime', 2)
-        sip.setapi('QUrl', 2)
-        sip.setapi('QVariant', 2)
-    except ValueError as e:
-        raise RuntimeError('Could not set PyQt4 API version (%s)' % e)
-
-    from PyQt4 import QtCore, QtGui, QtOpenGL
-    import PyQt4.QtGui as QtWidgets
-    from PyQt4.QtCore import pyqtSignal as Signal
-    from PyQt4.QtCore import pyqtSlot as Slot
-
-elif bindings == 'pyqt5':   # UNTESTED!
-    import sip
-    try:
-        sip.setapi('QDate', 2)
-        sip.setapi('QDateTime', 2)
-        sip.setapi('QString', 2)
-        sip.setapi('QTextStream', 2)
-        sip.setapi('QTime', 2)
-        sip.setapi('QUrl', 2)
-        sip.setapi('QVariant', 2)
-    except ValueError as e:
-        raise RuntimeError('Could not set PyQt5 API version (%s)' % e)
-
-    from PyQt5 import QtCore, QtGui, QtOpenGL
-    import PyQt5.QtGui as QtWidgets
+elif bindings == 'pyqt5':
+    from PyQt5 import QtCore, QtGui, QtOpenGL, QtWidgets
     from PyQt5.QtCore import pyqtSignal as Signal
     from PyQt5.QtCore import pyqtSlot as Slot
 
@@ -106,21 +70,14 @@ else:
     bindings = ''
 
 if not bindings:
-    raise ValueError("\n"+"*"*40+"\nThe pyFormex GUI requires Python bindings for the Qt libraries.\n These are available as PySide2, PySide, PyQt5 or PyQt4.\nI could not find neither of them, so I can not continue.\nInstall one of these bindings for Python3 (including its OpenGL component)\nand then retry."+"\n"+"*"*40)
+    raise ValueError("\n"+"*"*40+"\nThe pyFormex GUI requires Python bindings for the Qt libraries.\n These are available as PySide2 or PyQt5.\nI could not find neither of them, so I can not continue.\nInstall one of these bindings for Python3 (including its OpenGL component)\nand then retry."+"\n"+"*"*40)
 
 
 if bindings == 'pyside2':
     def QByteArrayToStr(self):
         """Convert a QByteArray to a Python3 str"""
         return str(self)[2:-1]
-elif bindings == 'pyside':
-    def QByteArrayToStr(self):
-        """Convert a QByteArray to a Python3 str"""
-        return str(self)
-else:
-    raise RuntimeError("Fatal error: currently only pyside2/pyside bindings are supported, not pyqt4/pyqt5")
-
-QtCore.QByteArray.toStr = QByteArrayToStr
+    QtCore.QByteArray.toStr = QByteArrayToStr
 
 
 # Some Qt wrappers
@@ -139,8 +96,6 @@ class QImage(QtGui.QImage):
         QtGui.QImage.__init__(self, *args)
 
 
-
-
 # Load X11 color names
 
 def loadX11Colors(filename):
