@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -48,13 +48,13 @@ class Vector4(np.ndarray):
     Examples
     --------
     >>> Vector4([1, 2, 3])
-    Vector4([[ 1.,  2.,  3.,  1.]])
+    Vector4([[1., 2., 3., 1.]])
     >>> Vector4([[1, 2, 3],[4, 5, 6]])
-    Vector4([[ 1.,  2.,  3.,  1.],
-             [ 4.,  5.,  6.,  1.]])
+    Vector4([[1., 2., 3., 1.],
+             [4., 5., 6., 1.]])
     >>> Vector4([[1, 2, 3, 0], [4., 5., 6., 1.]])
-    Vector4([[ 1.,  2.,  3.,  0.],
-             [ 4.,  5.,  6.,  1.]])
+    Vector4([[1., 2., 3., 0.],
+             [4., 5., 6., 1.]])
     >>> Vector4([[1,2,3]]).dtype
     dtype('float32')
 
@@ -92,10 +92,10 @@ class Matrix4(np.ndarray):
     --------
     >>> I = Matrix4()
     >>> print(I)
-    [[ 1.  0.  0.  0.]
-     [ 0.  1.  0.  0.]
-     [ 0.  0.  1.  0.]
-     [ 0.  0.  0.  1.]]
+    [[1.  0.  0.  0.]
+     [0.  1.  0.  0.]
+     [0.  0.  1.  0.]
+     [0.  0.  0.  1.]]
 
     We can first scale and then rotate, or first rotate and then scale (with
     another scaling factor):
@@ -103,10 +103,10 @@ class Matrix4(np.ndarray):
     >>> a = I.scale([4.,4.,4.]).rotate(45.,[0.,0.,1.])
     >>> b = I.rotate(45.,[0.,0.,1.]).scale([2.,2.,2.])
     >>> a
-    Matrix4([[ 0.,  4.,  0.,  0.],
-             [-4.,  0.,  0.,  0.],
-             [ 0.,  0.,  8.,  0.],
-             [ 0.,  0.,  0.,  1.]])
+    Matrix4([[ 0., 4., 0., 0.],
+             [-4., 0., 0., 0.],
+             [ 0., 0., 8., 0.],
+             [ 0., 0., 0., 1.]])
     >>> (a==b).all()
     True
     """
@@ -150,8 +150,8 @@ class Matrix4(np.ndarray):
         Example:
 
         >>> Matrix4().gl()
-        Matrix4([ 1.,  0.,  0.,  0.,  0.,  1.,  0.,  0.,  0.,  0.,  1.,  0.,  0.,
-                 0.,  0.,  1.])
+        Matrix4([1., 0., 0., 0., 0., 1., 0., 0., 0., 0., 1., 0., 0.,
+            0., 0., 1.], dtype=float32)
         """
         if self._gl is None:
             self._gl = self.flatten().astype(np.float32)
@@ -200,10 +200,10 @@ class Matrix4(np.ndarray):
         Example:
 
         >>> Matrix4().translate([1.,2.,3.])
-        Matrix4([[ 1.,  0.,  0.,  0.],
-                 [ 0.,  1.,  0.,  0.],
-                 [ 0.,  0.,  1.,  0.],
-                 [ 1.,  2.,  3.,  1.]])
+        Matrix4([[1., 0., 0., 0.],
+                 [0., 1., 0., 0.],
+                 [0., 0., 1., 0.],
+                 [1., 2., 3., 1.]])
         """
         vector = at.checkArray(vector, (3,), 'f')
         self.trl += np.dot(vector, self.rot)
@@ -230,10 +230,10 @@ class Matrix4(np.ndarray):
         Example:
 
         >>> Matrix4().rotate(90.,[0.,1.,0.])
-        Matrix4([[ 0.,  0., -1.,  0.],
-                 [ 0.,  1.,  0.,  0.],
-                 [ 1.,  0.,  0.,  0.],
-                 [ 0.,  0.,  0.,  1.]])
+        Matrix4([[ 0., 0., -1., 0.],
+                 [ 0., 1.,  0., 0.],
+                 [ 1., 0.,  0., 0.],
+                 [ 0., 0.,  0., 1.]])
 
         """
         ## !! TRANSPOSE!!
@@ -264,10 +264,10 @@ class Matrix4(np.ndarray):
         Example:
 
         >>> Matrix4().scale([1.,2.,3.])
-        Matrix4([[ 1.,  0.,  0.,  0.],
-                 [ 0.,  2.,  0.,  0.],
-                 [ 0.,  0.,  3.,  0.],
-                 [ 0.,  0.,  0.,  1.]])
+        Matrix4([[1., 0., 0., 0.],
+                 [0., 2., 0., 0.],
+                 [0., 0., 3., 0.],
+                 [0., 0., 0., 1.]])
         """
         vector = at.checkArray(vector, (3,), 'f')
         for i in range(3):
