@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -323,13 +323,13 @@ class Curve(Geometry):
         --------
         >>> PL = PolyLine([[0,0,0],[1,0,0],[1,1,0]])
         >>> print(PL.atApproximate(nseg=6))
-        [ 0.    0.33  0.67  1.    1.33  1.67  2.  ]
+        [0.   0.33 0.67 1.   1.33 1.67 2.  ]
         >>> print(PL.atApproximate(ndiv=3))
-        [ 0.    0.33  0.67  1.    1.33  1.67  2.  ]
+        [0.   0.33 0.67 1.   1.33 1.67 2.  ]
         >>> print(PL.atApproximate(ndiv=(2,4)))
-        [ 0.    0.5   1.    1.25  1.5   1.75  2.  ]
+        [0.   0.5  1.   1.25 1.5  1.75 2.  ]
         >>> print(PL.atApproximate(ndiv=(2,)))
-        [ 0.   0.5  1. ]
+        [0.  0.5 1. ]
 
         """
         if ndiv is not None:
@@ -937,9 +937,9 @@ class PolyLine(Curve):
         >>> print(C1.cosAngles())
         [-0.71  0.71  0.    0.    1.  ]
         >>> print(C2.cosAngles())
-        [ 0.    0.71  0.    0.    0.71]
+        [0.   0.71 0.   0.   0.71]
         >>> print(C3.cosAngles())
-        [ 0.    0.71  0.    0.    0.71  1.  ]
+        [0.   0.71 0.   0.   0.71 1.  ]
         """
         d = self.directions()
         return at.vectorPairCosAngle(np.roll(d, 1, axis=0), d)
@@ -1090,7 +1090,7 @@ class PolyLine(Curve):
                 print("COMPENSATED B0: %s" % BM)
                 print("Compensate at start")
                 print(BM, B[0])
-                a = at.vectorPairAngle(B[0], BM) / at.DEG
+                a = at.vectorPairAngle(B[0], BM)
                 print("ANGLE to compensate: %s" % a)
                 sa = np.sign(at.projection(np.cross(B[0], BM), T[0]))
                 print("Sign of angle: %s" % sa)
@@ -1102,7 +1102,7 @@ class PolyLine(Curve):
 
                 print("Compensate at end")
                 print(BM, B0)
-                a = at.vectorPairAngle(B0, BM) / at.DEG
+                a = at.vectorPairAngle(B0, BM)
                 print("ANGLE to compensate: %s" % a)
                 sa = np.sign(at.projection(np.cross(BM, B0), T[-1]))
                 print("Sign of angle: %s" % sa)
@@ -2290,6 +2290,7 @@ def circle():
 class Arc3(Curve):
     """A class representing a circular arc."""
     # TODO: approx returns a PolyLine that does not start from coords[0]. Why?
+    # TODO: store angles in degrees?
     def __init__(self, coords):
         """Create a circular arc.
 
@@ -2309,9 +2310,9 @@ class Arc3(Curve):
 
         r, C, n = gt.triangleCircumCircle(self.coords.reshape(-1, 3, 3))
         self.radius, self.center, self.normal = r[0], C[0], n[0]
-        self.angles = at.vectorPairAngle(Coords([1., 0., 0.]), self.coords-self.center)
+        self.angles = at.vectorPairAngle(Coords([1., 0., 0.]), self.coords-self.center, angle_spec=at.RAD)
         print("Radius %s, Center %s, Normal %s" % (self.radius, self.center, self.normal))
-        print("ANGLES=%s" % (self.angles))
+        print("ANGLES (radians) = %s" % (self.angles))
         return C
 
 
