@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -41,17 +41,25 @@ from pyformex.multi import multitask, cpu_count, splitar
 def isosurface(data, level, nproc=-1, tet=0):
     """Create an isosurface through data at given level.
 
-    - `data`: (nx,ny,nz) shaped array of data values at points with
-      coordinates equal to their indices. This defines a 3D volume
-      [0,nx-1], [0,ny-1], [0,nz-1]
-    - `level`: data value at which the isosurface is to be constructed
-    - `nproc`: number of parallel processes to use. On multiprocessor machines
-      this may be used to speed up the processing. If <= 0 , the number of
-      processes will be set equal to the number of processors, to achieve
-      a maximal speedup.
+    Parameters
+    ----------
+    data: :term:`array_like`
+        An (nx,ny,nz) shaped float array of data values at points with
+        coordinates equal to their indices. This defines a 3D volume
+        [0,nx-1], [0,ny-1], [0,nz-1].
+    level: float
+        The data value for which the isosurface is to be constructed.
+    nproc: int
+        The number of parallel processes to use. On multiprocessor machines
+        this may be used to speed up the processing. If <= 0 , the number of
+        processes will be set equal to the number of available processors,
+        to achieve a maximal speedup.
 
-    Returns an (ntr,3,3) array defining the triangles of the isosurface.
-    The result may be empty (if level is outside the data range).
+    Returns
+    -------
+    array:
+        An (ntr,3,3) float array defining the triangles of the isosurface.
+        The result may be empty (if level is outside the data range).
     """
     if nproc is None:
         nproc = -1
@@ -84,18 +92,26 @@ def isosurface(data, level, nproc=-1, tet=0):
 def isoline(data, level, nproc=-1):
     """Create an isocontour through data at given level.
 
-    - `data`: (nx,ny,nz) shaped array of data values at points with
-      coordinates equal to their indices. This defines a 2D area
-      [0,nx-1], [0,ny-1]
-    - `level`: data value at which the isocontour is to be constructed
-    - `nproc`: number of parallel processes to use. On multiprocessor machines
-      this may be used to speed up the processing. If <= 0 , the number of
-      processes will be set equal to the number of processors, to achieve
-      a maximal speedup.
+    Parameters
+    ----------
+    data: :term:`array_like`
+        An (nx,ny) shaped array of data values at points with
+        coordinates equal to their indices. This defines a 2D area
+        [0,nx-1], [0,ny-1].
+    level: float
+        The data value for which the isocontour is to be constructed.
+    nproc: int
+        The number of parallel processes to use. On multiprocessor machines
+        this may be used to speed up the processing. If <= 0 , the number of
+        processes will be set equal to the number of available processors,
+        to achieve a maximal speedup.
 
-    Returns an (nseg,2,2) array defining the 2D coordinates of the
-    segments of the isocontour.
-    The result may be empty (if level is outside the data range).
+    Returns
+    -------
+    array:
+        An (nseg,2,2) float array defining the 2D coordinates of the
+        segments of the isocontour.
+        The result may be empty (if level is outside the data range).
     """
     if nproc is None:
         nproc = -1
@@ -125,5 +141,4 @@ def isoline(data, level, nproc=-1):
     return seg
 
 
-
 # End
