@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -38,7 +38,7 @@ from pyformex.coords import bbox
 from pyformex.gui import draw as gs
 
 
-class Objects(object):
+class Objects():
     """A selection of objects from the pyFormex Globals().
 
     The class provides facilities to filter the global objects by their type
@@ -74,7 +74,7 @@ class Objects(object):
         self.like = like
         self.filter = filter
         self.names = []
-        self.values = []
+        self._values = []
         self.clear()
         if namelist:
             self.set(namelist)
@@ -95,7 +95,7 @@ class Objects(object):
         if isinstance(names, str):
             names = [names]
         self.names = [s for s in names if isinstance(s, str)]
-        self.values = [gs.named(s) for s in self.names]
+        self._values = [gs.named(s) for s in self.names]
 
 
     def append(self, name, value=None):
@@ -109,7 +109,7 @@ class Objects(object):
             value = gs.named(name)
         else:
             gs.export({name: value})
-        self.values.append(value)
+        self._values.append(value)
 
 
     def clear(self):
@@ -164,9 +164,9 @@ class Objects(object):
         If copy==True, the values are copied, so that the variables' current
         values can be changed inplace without affecting the remembered values.
         """
-        self.values = [gs.named(n) for n in self.names]
+        self._values = [gs.named(n) for n in self.names]
         if copy:
-            self.values = [deepcopy(n) for n in self.values]
+            self._values = [deepcopy(n) for n in self._values]
 
 
     def changeValues(self, newvalues):
@@ -183,7 +183,7 @@ class Objects(object):
 
     def undoChanges(self):
         """Undo the last changes of the values."""
-        gs.export2(self.names, self.values)
+        gs.export2(self.names, self._values)
 
 
     def check(self, *, allowed=None, single=False, warn=True):
@@ -225,10 +225,11 @@ class Objects(object):
             if warn:
                 pf.warning(f"You should select exactly one {self.object_type}")
             return None
+        ret = self.values()
         if single:
-            return gs.named(self.names[0])
+            return ret[0]
         else:
-            return [gs.named(n) for n in self.names]
+            return ret
 
 
     # TODO: this could/should become an option of check
@@ -247,13 +248,23 @@ class Objects(object):
         return sel
 
 
+    def keys(self):
+        """Return the names of the currently selected objects."""
+        return self.names
+
+
+    def values(self):
+        """Return the values of the currently selected objects."""
+        return [gs.named(n) for n in self.names]
+
+
     def odict(self):
         """Return the currently selected items as a dictionary.
 
         Returns a dict with the currently selected objects in the order
         of the selection.names.
         """
-        return dict(zip(self.names, self.check(warn=False)))
+        return dict(zip(self.names, self.values()))
 
 
     def ask(self, single=False, allowed=None):
@@ -320,12 +331,12 @@ class Objects(object):
         """Write objects to a geometry file."""
         objects = self.odict()
         if objects:
-            gs.writeGeomFile(filename, objects)
+            filewrite.writePGF(filename, objects)
 
 
     def readFromFile(self, filename):
         """Read objects from a geometry file."""
-        res = readGeomFile(filename)
+        res = fileread.readPGF(filename)
         gs.export(res)
         self.set(res.keys())
 
@@ -378,7 +389,7 @@ class DrawableObjects(Objects):
         old are drawn in yellow, new in the current color.
         """
         self.draw()
-        gs.draw(self.values, color='yellow', bbox=None, clear=False, wait=False)
+        gs.draw(self._values, color='yellow', bbox=None, clear=False, wait=False)
 
 
     def undoChanges(self):
