@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -170,12 +170,13 @@ class ElemSection(CDict):
         self.extra = None
         self.options = None
         CDict.__init__(self, **kargs)
-        self.addMaterial(material)
-        self.addSection(section)
+        if section is not None:
+            self.addSection(section)
+        if material is not None:
+            self.addMaterial(material)
         if orientation is not None:
             self.orientation = orientation
 
-
     def addMaterial(self, material):
         """Create or replace the material properties of the element.
 
@@ -191,12 +192,9 @@ class ElemSection(CDict):
         elif isinstance(material, dict):
             _matDB[material['name']] = CDict(material)
             self.material = _matDB[material['name']]
-        elif material is None:
-            self.material=material
         else:
             raise ValueError("Expected a string or a dict")
 
-
     def addSection(self, section):
         """Create or replace the section properties of the element.
 
@@ -215,12 +213,9 @@ class ElemSection(CDict):
             # print(section)
             _secDB[section['name']] = CDict(section)
             self.section = _secDB[section['name']]
-        elif section is None:
-            self.section = section
         else:
             raise ValueError("Expected a string or a dict")
 
-
     def computeSection(self, section):
         """Compute the section characteristics of specific sections."""
         if 'sectiontype' not in section:
