@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -124,20 +124,6 @@ class Varray(object):
         Note that two subsequent elements may be equal, corresponding with
         an empty row.
 
-
-    **Attributes**
-
-    Attributes
-    ----------
-    nrows: int
-        The number of rows in the table
-    width: int
-        The length of the longest row in the table
-    size: int
-        The total number of entries in the table
-    shape: tuple of two ints
-        The combined (``nrows``,``width``) values.
-
     Examples
     --------
     Create a Varray from a nested list:
@@ -249,6 +235,20 @@ class Varray(object):
     [[0 2 4]]
 
     """
+    # REMOVED
+
+    # **Attributes**
+
+    # Attributes
+    # ----------
+    # nrows: int
+    #     The number of rows in the table
+    # width: int
+    #     The length of the longest row in the table
+    # size: int
+    #     The total number of entries in the table
+    # shape: tuple of two ints
+    #     The combined (``nrows``,``width``) values.
 
     def __init__(self, data=[], ind=None):
         """Initialize the Varray. See the class docstring."""
